
import React from 'react';
import { motion } from 'framer-motion';
import { Button } from '@/components/ui/button';
import { Menu, Bike, Briefcase, Info, Users, MessageSquare } from 'lucide-react';

const NavLink = ({ href, children, icon }) => (
  <motion.a
    href={href}
    className="flex items-center text-gray-700 hover:text-purple-700 transition-colors duration-300 font-medium"
    whileHover={{ y: -2 }}
  >
    {icon && React.createElement(icon, { size: 18, className: "mr-2" })}
    {children}
  </motion.a>
);

const Navbar = () => {
  const [isMobileMenuOpen, setIsMobileMenuOpen] = React.useState(false);

  return (
    <motion.nav
      initial={{ y: -100 }}
      animate={{ y: 0 }}
      transition={{ duration: 0.5 }}
      className="bg-white/90 backdrop-blur-md shadow-lg sticky top-0 z-50"
    >
      <div className="container mx-auto px-4">
        <div className="flex items-center justify-between h-20">
          <motion.div whileHover={{ scale: 1.05 }} className="flex items-center text-3xl font-bold text-purple-700 cursor-pointer">
            <Bike size={36} className="mr-2 text-purple-600" />
            PedalReklam
          </motion.div>
          
          <div className="hidden md:flex items-center space-x-6">
            <NavLink href="#home" icon={Bike}>Ana Sayfa</NavLink>
            <NavLink href="#services" icon={Briefcase}>Hizmetler</NavLink>
            <NavLink href="#references" icon={Users}>Referanslar</NavLink>
            <NavLink href="#about" icon={Info}>Hakkımızda</NavLink>
            <NavLink href="#contact" icon={MessageSquare}>İletişim</NavLink>
          </div>

          <div className="flex items-center">
            <Button 
              onClick={() => {
                const contactSection = document.getElementById('contact');
                if (contactSection) {
                  contactSection.scrollIntoView({ behavior: 'smooth' });
                }
              }}
              className="hidden md:inline-flex bg-gradient-to-r from-purple-600 to-indigo-600 text-white hover:from-purple-700 hover:to-indigo-700 transition-all duration-300 transform hover:scale-105 shadow-md px-6 py-2.5"
            >
              Teklif Alın
            </Button>
            <div className="md:hidden ml-4">
              <Button variant="ghost" size="icon" onClick={() => setIsMobileMenuOpen(!isMobileMenuOpen)}>
                <Menu size={28} className="text-purple-700" />
              </Button>
            </div>
          </div>
        </div>
      </div>
      {isMobileMenuOpen && (
        <motion.div 
          initial={{ opacity: 0, height: 0 }}
          animate={{ opacity: 1, height: 'auto' }}
          exit={{ opacity: 0, height: 0 }}
          className="md:hidden bg-white/95 backdrop-blur-sm shadow-lg py-4 absolute w-full"
        >
          <div className="container mx-auto px-4 flex flex-col space-y-4">
            <NavLink href="#home" icon={Bike}>Ana Sayfa</NavLink>
            <NavLink href="#services" icon={Briefcase}>Hizmetler</NavLink>
            <NavLink href="#references" icon={Users}>Referanslar</NavLink>
            <NavLink href="#about" icon={Info}>Hakkımızda</NavLink>
            <NavLink href="#contact" icon={MessageSquare}>İletişim</NavLink>
            <Button 
              onClick={() => {
                const contactSection = document.getElementById('contact');
                if (contactSection) {
                  contactSection.scrollIntoView({ behavior: 'smooth' });
                }
                setIsMobileMenuOpen(false);
              }}
              className="w-full bg-gradient-to-r from-purple-600 to-indigo-600 text-white hover:from-purple-700 hover:to-indigo-700 transition-all duration-300 transform hover:scale-105 shadow-md px-6 py-2.5"
            >
              Teklif Alın
            </Button>
          </div>
        </motion.div>
      )}
    </motion.nav>
  );
};

export default Navbar;
